@@ -20,6 +20,8 @@ const DEFAULT_RDR_BUFFER_CAPACITY: usize = 16 * (1 << 10);
 pub const DEFAULT_WTR_BUFFER_CAPACITY: usize = 64 * (1 << 10);
 // number of rows for csv_sniffer to sample
 const DEFAULT_SNIFFER_SAMPLE: usize = 200;
+// number of bytes to check for UTF8 encoding
+const DEFAULT_UTF8_CHECK_BUFFER_LEN: usize = 8192;
 
 #[derive(Clone, Copy, Debug)]
 pub struct Delimiter(pub u8);
@@ -78,6 +80,8 @@ pub struct Config {
     double_quote: bool,
     escape: Option<u8>,
     quoting: bool,
+    autoindex: bool,
+    checkutf8: bool,
 }
 
 // Empty trait as an alias for Seek and Read that avoids auto trait errors
@@ -139,6 +143,8 @@ impl Config {
             double_quote: true,
             escape: None,
             quoting: true,
+            autoindex: env::var("QSV_AUTOINDEX").is_ok(),
+            checkutf8: env::var("QSV_SKIPUTF8_CHECK").is_err(),
         }
     }
 
@@ -253,10 +259,18 @@ impl Config {
     pub fn reader_file(&self) -> io::Result<csv::Reader<fs::File>> {
         match self.path {
             None => Err(io::Error::new(
-                io::ErrorKind::Other,
+                io::ErrorKind::InvalidInput,
                 "Cannot use <stdin> here",
             )),
-            Some(ref p) => fs::File::open(p).map(|f| self.from_reader(f)),
+            Some(ref p) => {
+                if !self.is_utf8_encoded() {
+                    return Err(io::Error::new(
+                        io::ErrorKind::InvalidData,
+                        format!("{p:?} is not UTF8 encoded."),
+                    ));
+                }
+                fs::File::open(p).map(|f| self.from_reader(f))
+            }
         }
     }
 
@@ -267,28 +281,84 @@ impl Config {
                 let mut buffer: Vec<u8> = Vec::new();
                 let stdin = io::stdin();
                 stdin.lock().read_to_end(&mut buffer)?;
+                // check if its utf8-encoded
+                if self.checkutf8 {
+                    let s = String::from_utf8_lossy(&buffer);
+                    debug!("checking stdin encoding...");
+                    if s.contains(std::char::REPLACEMENT_CHARACTER) {
+                        return Err(io::Error::new(
+                            io::ErrorKind::InvalidData,
+                            "<stdin> is not UTF8 encoded.",
+                        ));
+                    }
+                }
                 self.from_reader(Box::new(io::Cursor::new(buffer)))
             }
-            Some(ref p) => self.from_reader(Box::new(fs::File::open(p).unwrap())),
+            Some(ref p) => {
+                if !self.is_utf8_encoded() {
+                    return Err(io::Error::new(
+                        io::ErrorKind::InvalidData,
+                        format!("{p:?} is not UTF8 encoded."),
+                    ));
+                }
+                self.from_reader(Box::new(fs::File::open(p).unwrap()))
+            }
         })
     }
 
+    // qsv only works safely with utf8 encoded files
+    // check first DEFAULT_UTF8_CHECK_BUFFER_LEN bytes
+    // of file to quickly check if its utf8
+    fn is_utf8_encoded(&self) -> bool {
+        if !self.checkutf8 {
+            return true;
+        }
+        if let Some(path_buf) = &self.path {
+            debug!("checking encoding...");
+            let mut f = fs::File::open(path_buf).unwrap();
+            let fsize = f.metadata().unwrap().len() as usize;
+            let mut buffer_size = DEFAULT_UTF8_CHECK_BUFFER_LEN;
+            if fsize < buffer_size {
+                buffer_size = fsize;
+            }
+            let mut buffer = vec![0; buffer_size];
+            if f.read_exact(&mut buffer).is_ok() {
+                let s = String::from_utf8_lossy(&buffer);
+                return !s.contains(std::char::REPLACEMENT_CHARACTER);
+            }
+        }
+        false
+    }
+
+    fn autoindex_file(&self) {
+        if let Some(path_buf) = &self.path {
+            let path_clone = path_buf.clone();
+            let path_str = path_clone.into_os_string().into_string().unwrap();
+            let index_argv: Vec<&str> = vec!["", "index", &path_str];
+            crate::cmd::index::run(&*index_argv).unwrap();
+            debug!("autoindex for {path_str} created");
+        }
+    }
+
     pub fn index_files(&self) -> io::Result<Option<(csv::Reader<fs::File>, fs::File)>> {
         let (csv_file, idx_file) = match (&self.path, &self.idx_path) {
             (&None, &None) => return Ok(None),
             (&None, &Some(_)) => {
                 return Err(io::Error::new(
-                    io::ErrorKind::Other,
+                    io::ErrorKind::InvalidInput,
                     "Cannot use <stdin> with indexes",
-                    // Some(format!("index file: {}", p.display()))
                 ));
             }
             (&Some(ref p), &None) => {
                 // We generally don't want to report an error here, since we're
-                // passively trying to find an index.
+                // passively trying to find an index, so we just log the warning...
                 let idx_file = match fs::File::open(&util::idx_path(p)) {
                     Err(e) => {
-                        warn!("No index file found - {p:?}: {e}");
+                        if self.autoindex {
+                            self.autoindex_file();
+                        } else {
+                            warn!("No index file found - {p:?}: {e}");
+                        }
                         return Ok(None);
                     }
                     Ok(f) => f,
@@ -303,11 +373,16 @@ impl Config {
         let data_modified = util::last_modified(&csv_file.metadata()?);
         let idx_modified = util::last_modified(&idx_file.metadata()?);
         if data_modified > idx_modified {
-            return Err(io::Error::new(
-                io::ErrorKind::Other,
-                "The CSV file was modified after the index file. \
+            if self.autoindex {
+                debug!("index stale... autoindexing...");
+                self.autoindex_file();
+            } else {
+                return Err(io::Error::new(
+                    io::ErrorKind::Other,
+                    "The CSV file was modified after the index file. \
                  Please re-create the index.",
-            ));
+                ));
+            }
         }
         let csv_rdr = self.from_reader(csv_file);
         Ok(Some((csv_rdr, idx_file)))
@@ -322,14 +397,40 @@ impl Config {
 
     pub fn io_reader(&self) -> io::Result<Box<dyn io::Read + 'static>> {
         Ok(match self.path {
-            None => Box::new(io::stdin()),
-            Some(ref p) => match fs::File::open(p) {
-                Ok(x) => Box::new(x),
-                Err(err) => {
-                    let msg = format!("failed to open {}: {}", p.display(), err);
-                    return Err(io::Error::new(io::ErrorKind::NotFound, msg));
+            None => {
+                if self.checkutf8 {
+                    let stdin_reader = io::stdin();
+                    let mut buffer: Vec<u8> = Vec::new();
+                    stdin_reader.lock().read_to_end(&mut buffer)?;
+                    // check if its utf8-encoded
+                    let s = String::from_utf8_lossy(&buffer);
+                    debug!("checking stdin encoding...");
+                    if s.contains(std::char::REPLACEMENT_CHARACTER) {
+                        return Err(io::Error::new(
+                            io::ErrorKind::InvalidData,
+                            "<stdin> is not UTF8 encoded.",
+                        ));
+                    }
+                    Box::new(io::Cursor::new(buffer))
+                } else {
+                    Box::new(io::stdin())
                 }
-            },
+            }
+            Some(ref p) => {
+                if !self.is_utf8_encoded() {
+                    return Err(io::Error::new(
+                        io::ErrorKind::InvalidData,
+                        format!("{p:?} is not UTF8 encoded."),
+                    ));
+                }
+                match fs::File::open(p) {
+                    Ok(x) => Box::new(x),
+                    Err(err) => {
+                        let msg = format!("failed to open {}: {}", p.display(), err);
+                        return Err(io::Error::new(io::ErrorKind::NotFound, msg));
+                    }
+                }
+            }
         })
     }
 
