@@ -46,7 +46,6 @@ macro_rules! command_list {
     enum        Add a new column enumerating CSV lines
     exclude     Excludes the records in one CSV from another
     explode     Explode rows based on some column separator
-    fetch       Create a new column or fetch values from a URL column
     fill        Fill empty values
     fixlengths  Makes all records have same length
     flatten     Show one field per line
@@ -60,14 +59,16 @@ macro_rules! command_list {
     jsonl       Convert newline-delimited JSON files to CSV
     partition   Partition CSV data based on a column value
     pseudo      Pseudonymise the values of a column
-    sample      Randomly sample CSV data
     rename      Rename the columns of CSV data efficiently
     replace     Replace patterns in CSV data
     reverse     Reverse rows of CSV data
+    sample      Randomly sample CSV data
+    schema      Generate JSON Schema from CSV data
     search      Search CSV data with a regex
     searchset   Search CSV data with a regex set
     select      Select, re-order, duplicate or drop columns
     slice       Slice records from CSV
+    sniff       Quickly sniff CSV metadata
     sort        Sort CSV data in alphabetical, numerical, reverse or random order
     split       Split CSV data into many files
     stats       Infer data types and compute descriptive statistics
@@ -97,10 +98,11 @@ Options:
     -u, --update         Update qsv to the latest release from GitHub.
     -h, --help           Display this message
     <command> -h         Display the command help message
-    -v, --version        Print version info, mem allocator, max_jobs, num_cpus then exit
+    -v, --version        Print version info, mem allocator, features installed, 
+                         max_jobs, num_cpus then exit
 
-Commands:",
-    command_list!()
+* sponsored by datHere - Data Infrastructure Engineering
+"
 );
 
 #[derive(Deserialize)]
@@ -199,7 +201,6 @@ enum Command {
     Enum,
     Exclude,
     Explode,
-    Fetch,
     Fill,
     FixLengths,
     Flatten,
@@ -217,10 +218,12 @@ enum Command {
     Replace,
     Reverse,
     Sample,
+    Schema,
     Search,
     SearchSet,
     Select,
     Slice,
+    Sniff,
     Sort,
     Split,
     Stats,
@@ -249,7 +252,6 @@ impl Command {
             Command::Enum => cmd::enumerate::run(argv),
             Command::Exclude => cmd::exclude::run(argv),
             Command::Explode => cmd::explode::run(argv),
-            Command::Fetch => cmd::fetch::run(argv),
             Command::Fill => cmd::fill::run(argv),
             Command::FixLengths => cmd::fixlengths::run(argv),
             Command::Flatten => cmd::flatten::run(argv),
@@ -271,10 +273,12 @@ impl Command {
             Command::Replace => cmd::replace::run(argv),
             Command::Reverse => cmd::reverse::run(argv),
             Command::Sample => cmd::sample::run(argv),
+            Command::Schema => cmd::schema::run(argv),
             Command::Search => cmd::search::run(argv),
             Command::SearchSet => cmd::searchset::run(argv),
             Command::Select => cmd::select::run(argv),
             Command::Slice => cmd::slice::run(argv),
+            Command::Sniff => cmd::sniff::run(argv),
             Command::Sort => cmd::sort::run(argv),
             Command::Split => cmd::split::run(argv),
             Command::Stats => cmd::stats::run(argv),
